/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import metridoc.dsl.JobBuilder
import metridoc.dsl.JobRunner
import metridoc.utils.PropertyUtils

configureJobBuilder {LinkedHashMap args = null, JobBuilder jobBuilder ->
    if (args && args.jobs) {
        if (args.jobs instanceof Class) {
            jobBuilder.load(args.jobs)
        }

        if (args.jobs instanceof List) {
            args.jobs.each {job ->
                if (job instanceof Class) {
                    jobBuilder.load(job)
                }
            }
        }
    }
}

def isHook = {String prefix, String key, Object value ->
    key.startsWith(prefix) &&
            key.size() > 3 &&
            value instanceof Closure
}

def addHooks = {String prefix, LinkedHashMap args, JobBuilder jobBuilder ->

    if (args) {
        args.keySet().each {String key ->
            if (isHook(prefix, key, args[key])) {
                jobBuilder.services[key.toLowerCase()] = args[key]
            }
        }
    }
}

//add hooks
configureJobBuilder {LinkedHashMap args = null, JobBuilder jobBuilder ->
    addHooks("pre", args, jobBuilder)
    addHooks("post", args, jobBuilder)
}

JobRunner.metaClass.loadProperties = {String... propertyFiles ->
    def util = new PropertyUtils()
    util.loadProperties(services, propertyFiles)
}

