/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.dsl

import java.util.Map.Entry

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 5/16/11
 * Time: 1:54 PM
 */
class Services implements Map{
    public static final PRE = "pre"
    public static final POST = "post"
    def Map serviceCache = new HashMap()
    def Set noOverride = []
    def Set overrideWithSameType = []

    @Override
    public java.lang.Object getProperty(String propertyName) {
        if(propertyName == "noOverride"){
          return noOverride
        }

        if(propertyName == "overrideWithSameType") {
            return overrideWithSameType
        }

        serviceCache[propertyName.toLowerCase()]
    }

    @Override
    public void setProperty(String propertyName, propertyValue) {
        propertyName = propertyName.toLowerCase()
        def oldValue = serviceCache[propertyName]

        if(noOverride.contains(propertyName)) {
            throw IllegalOverrideException.byServiceName(propertyName, oldValue, propertyValue)
        }

        if(oldValue && overrideWithSameType.contains(propertyName)) {
            if(oldValue.class != propertyValue.class) {
                throw IllegalOverrideException.byType(propertyName, oldValue, propertyValue)
            }
        }

        serviceCache[propertyName] = propertyValue
    }

    int size() {
        return serviceCache.size()
    }

    boolean isEmpty() {
        return serviceCache.isEmpty()
    }

    boolean containsKey(Object o) {
        return serviceCache.containsKey(((String) o).toLowerCase())
    }

    boolean containsValue(Object o) {
        return serviceCache.containsValue(o)
    }

    Object get(Object o) {
        return getProperty((String) o)
    }

    Object put(Object k, Object v) {
        def oldObject = getProperty(k)
        setProperty(k, v)
        return oldObject
    }

    Object remove(Object o) {
        return serviceCache.remove(o)
    }

    void putAll(Map map) {
        map.each {key, value ->
            setProperty(key, value)
        }
    }

    void clear() {
        serviceCache.clear()
    }

    Set keySet() {
        serviceCache.keySet()
    }

    Collection values() {
        serviceCache.values()
    }

    Set<Entry> entrySet() {
        serviceCache.entrySet()
    }
}
