/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.test;

import ch.qos.logback.classic.Level;
import ch.qos.logback.classic.Logger;
import metridoc.extension.ExtensionRunner;
import org.junit.Before;
import org.junit.Assert
import org.junit.BeforeClass;
import org.slf4j.LoggerFactory
import org.junit.After;


/**
 *
 * @author Tommy Barker
 */
class BaseTest extends Assert{

    private static final Level DEFAULT_LOG_LEVEL = Level.WARN

    protected Level getLoggingLevel() {
        return DEFAULT_LOG_LEVEL;
    }

    @Before
    public void setupLogging() {
        setupLogging(getLoggingLevel());
    }

    @After
    public void resetLogger() {
        setupLogging(DEFAULT_LOG_LEVEL)
    }

    static void setupLogging(Level level) {
        Logger logger = (Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
        logger.setLevel(level);
    }

    static File getFile(String path, String alternateBase) {
        def file = new File(path)

        if(!file.exists()) {
            file = new File("${alternateBase}/${path}")
        }

        assert file.exists()
        return file
    }
}

