/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package metridoc.utils;

import java.io.PrintWriter;
import java.io.StringWriter;

/**
 *
 * @author Tommy Barker
 */
public class ExceptionUtils {

    static String getAllMessages(Throwable t) {
        def message = new StrBuilder()
        message.appendln(getLine(t, false))

        while(t.cause) {
            message.appendln(getLine(t.cause, true))
            t = t.cause
        }

        return message.toString()
    }

    private static String getLine(Throwable t, boolean isCause) {
        def message = "${t.class.simpleName}: ${t.message}"

        if(isCause) {
            message = "caused by: ${message}"
        }

        return message
    }

    /**
     * retrieves the full text of a passed exception
     *
     * @param exception
     * @return the text of the full stack trace
     */
    public static String getStackTrace(Throwable exception) {
        StringWriter sw = new StringWriter();
        PrintWriter pw = new PrintWriter(sw, true);
        populateStackTrace(exception, pw);

        return sw.toString();
    }

    static void populateStackTrace(Throwable exception, PrintWriter pw) {
        exception.printStackTrace(pw);
        Throwable cause = exception.getCause();
        if (cause != null) {
            populateStackTrace(cause, pw);
        }
    }
}
